@@ -1,9 +1,12 @@
 epval_Bai1996 <- function(sam1, sam2, n.iter = 1000, seeds){
-	if(missing(seeds)) seeds <- NULL
-	if(length(seeds) != n.iter){
+	if(missing(seeds)){
 		seeds <- NULL
-		cat("The length of seeds does not match the specified n.iter.\n")
-		cat("Seeds for each permutation/resampling iteration are assigned randomly.\n")
+	}else{
+		if(length(seeds) != n.iter){
+			seeds <- NULL
+			cat("The length of seeds does not match the specified n.iter.\n")
+			cat("Seeds for each permutation/resampling iteration are assigned randomly.\n")
+		}
 	}
 	n1 <- dim(sam1)[1]
 	n2 <- dim(sam2)[1]
